@@ -103,6 +103,44 @@ class POI:
 
         self.poi_rebuild()
 
+    def on_bt_delete_poi(self,w,id, dialog):
+        print "delete poi id:",id
+        pNew = []
+        for p in self.poi:
+            if p[0] <> id:
+                pNew.append(p)
+        self.poi = []
+        self.poi = pNew
+        self.poi_rebuild()
+        self.on_bt_edit(None)
+        self.saveXml()
+        dialog.destroy()
+
+    def on_bt_edit(self, w):
+        d = hildon.Dialog()
+        d.set_title("POI edit")
+
+        mvbox = gtk.VBox()
+        panel = hildon.PannableArea()
+        panel.add_with_viewport(mvbox)
+        d.vbox.pack_start( panel, True,True)
+        panel.set_size_request(640, 280)
+
+        for p in self.poi:
+            hbox = gtk.HBox()
+            l = gtk.Label(p[1])
+            hbox.pack_start(l,False)
+            l = gtk.Label("")
+            hbox.pack_start(l,True)
+            bt = gtk.Button("del")
+            bt.connect( "clicked", self.on_bt_delete_poi, p[0], d )
+            hbox.pack_start(bt,False)
+            mvbox.pack_start(hbox,False)
+
+        d.show_all()
+        d.run()
+        d.destroy()
+
     def get_menu_widgets(self, dialog):
         hbox = gtk.HBox()
 
@@ -111,6 +149,7 @@ class POI:
         hbox.pack_start( bt_add, True)
 
         bt_edit = gtk.Button("Actions(%i)"%len(self.poi))
+        bt_edit.connect("clicked", self.on_bt_edit )
         hbox.pack_start( bt_edit, False)
 
         return hbox
