@@ -58,6 +58,10 @@ gtk.gdk.threads_init()
 name = "yosmapa"
 version = "0.18"
 """
+0.18-2
+    plugin[google_routesearch] add more icons
+    clien up distanse recalculation
+    plugin[POI] add delete action
 0.18
     plugin[google_routesearch] support for espeak in turn by turn mode :)
 0.17
@@ -618,15 +622,9 @@ class YosmapaOSD(gobject.GObject, osmgpsmap.GpsMapLayer):
                 if x >= c[0] and y >= c[1] and x<= c[2] and y<= c[3]:
                     print "c:",c
                     m = gtk.Menu()
+                    latc,lonc = self.osmMapa.get_may_current_ll()
+                    dis = self.osmMapa.distance_to_string( self.osmMapa.distance( latc, lonc, c[4], c[5]) )
 
-                    latc = self.osmMapa.osm.props.latitude
-                    lonc = self.osmMapa.osm.props.longitude
-                    dis = self.osmMapa.distance( latc, lonc, c[4], c[5])
-                    if dis > 1.0:
-                        dis = ("%.1f km"%dis)
-                    else:
-                        dis*=1000
-                        dis = ("%i m"%dis)
                     mi = gtk.MenuItem("___________Distans it: %s" % dis)
                     m.append(mi)
 
@@ -882,13 +880,8 @@ class UI(gtk.Window):
             #cr.move_to(x+2,y+line_height)
 
 
-            dis = self.distance( latc, lonc, lat, lon)
-            #print "arrow: a:",a," dist:",dis
-            if dis > 1.0:
-                cr.show_text("%.1f km"%dis)
-            else:
-                dis*=1000
-                cr.show_text("%i m"%dis)
+            dis = self.distance_to_string( self.distance( latc, lonc, lat, lon) )
+            cr.show_text("%s"%dis)
 
     def draw_cloud(self, cr, x, y, str, font_size = 13, Fifek = True):
         if x<0 or y<0:
